# QMCblip

QMC Based Learning of Interatomic Potentials

[![PyPI version](https://badge.fury.io/py/QMCblip.svg)](https://badge.fury.io/py/QMCblip) 
[![Build Status](https://github.com/NLESC-JCER/QMCblip/workflows/build/badge.svg)](https://github.com/NLESC-JCER/QMCblip/actions)
[![Coverage Status](https://coveralls.io/repos/github/NLESC-JCER/QMCblip/badge.svg?branch=master)](https://coveralls.io/github/NLESC-JCER/QMCblip?branch=master)

# Installation

You can install this package by cloning this repository:
```
git clone https://github.com/NLESC-JCER/QMCblip.git
cd QMCblip
pip install .
```

or by installing it from Pypi:
```
pip install qmcblip
```
## Documentation

The documentation of this code can be found on https://qmcblip.readthedocs.io/.
